# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def load_arguments(self, _):
    from knack.arguments import ArgumentsContext
    from azdata.cli.commands.config import _

    with ArgumentsContext(self, 'bdc settings set') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Sets the configured value for the provided settings. Multiple settings can be set using a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc settings show') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Shows information for the specified setting name(s).')
        )
        arg_context.argument(
            'filter_option',
            options_list=('--filter-option', '-f'),
            choices=('all', 'configurable', 'userconfigured', 'pending'),
            type=str.lower,
            help=_('Filter which cluster-scope settings are shown, rather than only \'User Configured\' settings. '
                   'Filters are available to show all settings (system-managed & user-configurable), all configurable '
                   'settings, or pending settings.')
        )
        arg_context.argument(
            'include_details',
            options_list=('--include-details', '-i'),
            action='store_true',
            help=_('Includes additional details for the settings chosen to be shown.')
        )
        arg_context.argument(
            'description',
            options_list=('--description', '-d'),
            action='store_true',
            help=_('Includes a description of the setting.')
        )
        arg_context.argument(
            'recursive',
            options_list=('--recursive', '-rec'),
            action='store_true',
            help=_('Shows the setting information for the cluster scope and all lower-scoped components '
                   '(services, resources).')
        )

    with ArgumentsContext(self, 'bdc settings apply') as arg_context:
        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force apply, the user will not be prompted for any confirmation and all issues will be printed '
                   'as part of stderr.')
        )

    with ArgumentsContext(self, 'bdc settings cancel-apply') as arg_context:
        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force cancel-apply, the user will not be prompted for any confirmation and all issues will '
                   'be printed as part of stderr.')
        )

    with ArgumentsContext(self, 'bdc sql settings set') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Sets the configured value for the provided settings. Multiple settings can be set using a comma '
                   'separated list.')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Sets the given setting(s) for the provided resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc hdfs settings set') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Sets the configured value for the provided settings. Multiple settings can be set using a comma '
                   'separated list.')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Sets the given setting(s) for the provided resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc spark settings set') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Sets the configured value for the provided settings. Multiple settings can be set using a comma '
                   'separated list.')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Sets the given setting(s) for the provided resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc gateway settings set') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Sets the configured value for the provided settings. Multiple settings can be set using a comma '
                   'separated list.')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Sets the given setting(s) for the provided resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc settings revert') as arg_context:
        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force revert, the user will not be prompted for any confirmation and all issues will be printed as '
                   'part of stderr.')
        )

    with ArgumentsContext(self, 'bdc sql settings show') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Shows information for the specified setting name(s).')
        )
        arg_context.argument(
            'filter_option',
            options_list=('--filter-option', '-f'),
            choices=('all', 'configurable', 'userconfigured', 'pending'),
            type=str.lower,
            help=_('Filter which cluster-scope settings are shown, rather than only \'User Configured\' settings. '
                   'Filters are available to show all settings (system-managed & user-configurable), all configurable '
                   'settings, or pending settings.')
        )
        arg_context.argument(
            'include_details',
            options_list=('--include-details', '-i'),
            action='store_true',
            help=_('Includes additional details for the settings chosen to be shown.')
        )
        arg_context.argument(
            'description',
            options_list=('--description', '-d'),
            action='store_true',
            help=_('Includes a description of the setting.')
        )
        arg_context.argument(
            'recursive',
            options_list=('--recursive', '-rec'),
            action='store_true',
            help=_('Shows the setting information for the given scope (service or service-resource) and all '
                   'lower-scoped components (resources).')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Shows the setting(s) information for the given resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc hdfs settings show') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Shows information for the specified setting name(s).')
        )
        arg_context.argument(
            'filter_option',
            options_list=('--filter-option', '-f'),
            choices=('all', 'configurable', 'userconfigured', 'pending'),
            type=str.lower,
            help=_('Filter which cluster-scope settings are shown, rather than only \'User Configured\' settings. '
                   'Filters are available to show all settings (system-managed & user-configurable), all configurable '
                   'settings, or pending settings.')
        )
        arg_context.argument(
            'include_details',
            options_list=('--include-details', '-i'),
            action='store_true',
            help=_('Includes additional details for the settings chosen to be shown.')
        )
        arg_context.argument(
            'description',
            options_list=('--description', '-d'),
            action='store_true',
            help=_('Includes a description of the setting.')
        )
        arg_context.argument(
            'recursive',
            options_list=('--recursive', '-rec'),
            action='store_true',
            help=_('Shows the setting information for the given scope (service or service-resource) and all '
                   'lower-scoped components (resources).')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Shows the setting(s) information for the given resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc spark settings show') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Shows information for the specified setting name(s).')
        )
        arg_context.argument(
            'filter_option',
            options_list=('--filter-option', '-f'),
            choices=('all', 'configurable', 'userconfigured', 'pending'),
            type=str.lower,
            help=_('Filter which cluster-scope settings are shown, rather than only \'User Configured\' settings. '
                   'Filters are available to show all settings (system-managed & user-configurable), all configurable '
                   'settings, or pending settings.')
        )
        arg_context.argument(
            'include_details',
            options_list=('--include-details', '-i'),
            action='store_true',
            help=_('Includes additional details for the settings chosen to be shown.')
        )
        arg_context.argument(
            'description',
            options_list=('--description', '-d'),
            action='store_true',
            help=_('Includes a description of the setting.')
        )
        arg_context.argument(
            'recursive',
            options_list=('--recursive', '-rec'),
            action='store_true',
            help=_('Shows the setting information for the given scope (service or service-resource) and all '
                   'lower-scoped components (resources).')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Shows the setting(s) information for the given resource(s). Resources can be specified as a comma '
                   'separated list.')
        )

    with ArgumentsContext(self, 'bdc gateway settings show') as arg_context:
        arg_context.argument(
            'settings',
            options_list=('--settings', '-s'),
            help=_('Shows information for the specified setting name(s).')
        )
        arg_context.argument(
            'filter_option',
            options_list=('--filter-option', '-f'),
            choices=('all', 'configurable', 'userconfigured', 'pending'),
            type=str.lower,
            help=_('Filter which cluster-scope settings are shown, rather than only \'User Configured\' settings. '
                   'Filters are available to show all settings (system-managed & user-configurable), all configurable '
                   'settings, or pending settings.')
        )
        arg_context.argument(
            'include_details',
            options_list=('--include-details', '-i'),
            action='store_true',
            help=_('Includes additional details for the settings chosen to be shown.')
        )
        arg_context.argument(
            'description',
            options_list=('--description', '-d'),
            action='store_true',
            help=_('Includes a description of the setting.')
        )
        arg_context.argument(
            'recursive',
            options_list=('--recursive', '-rec'),
            action='store_true',
            help=_('Shows the setting information for the given scope (service or service-resource) and all '
                   'lower-scoped components (resources).')
        )
        arg_context.argument(
            'resources',
            options_list=('--resources', '-r'),
            help=_('Shows the setting(s) information for the given resource(s). Resources can be specified as a comma '
                   'separated list.')
        )
