# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.config.api.configuration_router_api import ConfigurationRouterApi
from azdata.cli.commands.config.models.configuration_upgrade_request import ConfigurationUpgradeRequest
from azdata.cli.core.clients.controller_client import RefreshRetry
from azdata.cli.core.exceptions import ApiError, ControllerError
from azdata.cli.commands.config.models.configuration_setting_request_model import ConfigurationSettingRequestModel

# This file contains plugins for ControllerClient. The file name must be controller_service.py so
# that ControllerClient can import this module as plugins.

__all__ = ['ConfigResource']
latest_api_version = '2'

# ---------------------------------------------------------------------------- #
# Configuration: /config/*
# ---------------------------------------------------------------------------- #
class ConfigResource():

    @RefreshRetry
    def set_config(self, service, resource, settings, api_version=latest_api_version):
        """
        Set configuration
        """
        requestBody = ConfigurationSettingRequestModel(settings)
        try:
            api = ConfigurationRouterApi(api_client=self.api_client)
            if service != None and resource != None:
                # for settings of scope 'service and resource'
                #
                response = api.api_vversion_bdc_services_service_name_resources_resource_name_config_post(
                    service,
                    resource,
                    api_version,
                    body=requestBody
                )
            elif service != None:
                # for settings of scope 'service'
                #
                response = api.api_vversion_bdc_services_service_name_config_post(
                    service,
                    api_version,
                    body=requestBody
                )
            else:
                # for settings of scope 'cluster'
                #
                response = api.api_vversion_bdc_config_post(
                    api_version,
                    body=requestBody
                )
            return response
        except ApiError as e:
            raise ControllerError(e, status=e.status, response_json=e.response_json)

    @RefreshRetry
    def upgrade_config(self, description, abort, api_version=latest_api_version):
        """
        Upgrade configuration
        """
        requestBody = ConfigurationUpgradeRequest(description=description, abort_upgrade=abort)
        try:
            api = ConfigurationRouterApi(api_client=self.api_client)
            response = api.api_vversion_bdc_config_patch(api_version, body=requestBody)
            return response
        except ApiError as e:
            raise ControllerError(e, status=e.status, response_json=e.response_json)

    @RefreshRetry
    def show_config(self, service, resource, settings, filter_option, recursive, include_details, api_version=latest_api_version):
        """
        Get configuration
        """
        try:
            api = ConfigurationRouterApi(api_client=self.api_client)
            if service and resource:
                # for settings of scope 'service and resource'
                #
                response = api.api_vversion_bdc_services_service_name_resources_resource_name_config_get(
                    service_name=service,
                    resource_name=resource,
                    version=api_version,
                    filter_option=filter_option,
                    recursive=recursive,
                    settings=settings,
                    include_details=include_details
                )
            elif service:
                # for settings of scope 'service'
                #
                response = api.api_vversion_bdc_services_service_name_config_get(
                    service_name=service,
                    version=api_version,
                    filter_option=filter_option,
                    recursive=recursive,
                    settings=settings,
                    include_details=include_details
                )
            else:
                # for settings of scope 'cluster'
                #
                response = api.api_vversion_bdc_config_get(
                    version=api_version,
                    filter_option=filter_option,
                    recursive=recursive,
                    settings=settings,
                    include_details=include_details
                )
            return response
        except ApiError as e:
            raise ControllerError(e, status=e.status, response_json=e.response_json)

    @RefreshRetry
    def revert_config_settings(self, api_version=latest_api_version):
        """
        Revert pending settings
        """
        try:
            api = ConfigurationRouterApi(api_client=self.api_client)
            response = api.api_vversion_bdc_config_revert_patch(api_version)
            return response
        except ApiError as e:
            raise ControllerError(e, status=e.status, response_json=e.response_json)