# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from knack.help_files import helps
from azdata.cli.commands.config import _

# pylint: disable=line-too-long

helps['bdc settings'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('BDC settings commands.'))

helps['bdc sql settings'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('BDC settings commands for sql service.'))

helps['bdc spark settings'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('BDC settings commands for spark service.'))

helps['bdc hdfs settings'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('BDC settings commands for hdfs service.'))

helps['bdc gateway settings'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('BDC settings commands for gateway service.'))

helps['bdc settings set'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc settings set --settings bdc.telemetry.customerFeedback=false
""".format(
    short=_('Set cluster-scope settings.'),
    long=_('Set a cluster-scope setting. Specify the full name of the setting and the value. Run apply to apply the '
           'setting and update the BDC settings.'),
    ex1=_('Set the cluster default for "bdc.telemetry.customerFeedback".'))

helps['bdc sql settings set'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc sql settings set --settings mssql.sqlagent.enabled=true --resources master
        - name: {ex2}
          text: >
            azdata bdc sql settings set --settings mssql.numberOfCpus=10 --resources data-0 
""".format(
    short=_('Set sql service-scope settings.'),
    long=_('Provides the ability to set a service-scoped or resource-scoped setting. Specify the full name of the '
           'setting and the value. Does not apply the setting to the running BDC. Run apply to do so.'),
    ex1=_('Enable SQL agent in the SQL Server Master instance.'),
    ex2=_('Set the number of CPUs for SQL Server to 10 in the Data Pool.'))

helps['bdc spark settings set'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc spark settings set --settings spark-defaults-conf.spark.driver.cores=1,spark-defaults-conf.spark.driver.memory=1664m
        - name: {ex2}
          text: >
            azdata bdc spark settings set --settings spark-defaults-conf.spark.executor.cores=1 –resources storage-0
""".format(
    short=_('Set spark service-scope settings.'),
    long=_('Provides the ability to set a service-scoped or resource-scoped setting. Specify the full name of the '
           'setting and the value. Does not apply the setting to the running BDC. Run apply to do so.'),
    ex1=_('Set the default number of driver cores to 1 and driver memory to 1664m for the Spark service.'),
    ex2=_('Set the default number of executor cores to 1 for the Storage Pool.'))

helps['bdc hdfs settings set'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs settings set --settings hdfs-site dfs.datanode.provided.volume.readthrough=false
        - name: {ex2}
          text: >
            azdata bdc hdfs settings set --settings hdfs-site.dfs.replication=3 –resources storage-0
""".format(
    short=_('Set spark service-scope settings.'),
    long=_('Provides the ability to set a service-scoped or resource-scoped setting. Specify the full name of the '
           'setting and the value. Does not apply the setting to the running BDC. Run apply to do so.'),
    ex1=_('Disable volume readthrough.'),
    ex2=_('Set the default block replication factor to 3 for the Storage Pool.'))

helps['bdc gateway settings set'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc gateway settings set --settings gateway-site.gateway.httpclient.socketTimeout=100s –resources gateway
""".format(
    short=_('Set gateway service-scope settings.'),
    long=_('Provides the ability to set a service-scoped or resource-scoped setting. Specify the full name of the '
           'setting and the value. Does not apply the setting to the running BDC. Run apply to do so.'),
    ex1=_('Set the socket timeout for httpclient to 100s for gateway resource.'))

helps['bdc settings apply'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc settings apply
        - name: {ex2}
          text: >
            azdata bdc settings apply --force
""".format(
    short=_('Apply the pending settings changes to the BDC.'),
    long=_('Apply the pending settings changes to the BDC.'),
    ex1=_('Apply the pending settings changes to the BDC.'),
    ex2=_('Force apply, the user will not be prompted for any confirmation and all issues will be printed as part '
          'of stderr.'))

helps['bdc settings cancel-apply'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc settings cancel-apply
        - name: {ex2}
          text: >
            azdata bdc settings cancel-apply --force
""".format(
    short=_('Cancel the BDC settings apply.'),
    long=_('In the event of a failure during settings application, return the Big Data Cluster to its last running '
           'state. This command will be a no-op if applied to a running cluster. Previously pending settings '
           'changes will still be pending after the cancellation.'),
    ex1=_('Cancel the BDC settings apply.'),
    ex2=_('Force cancel-apply, the user will not be prompted for any confirmation and all issues will be printed as '
          'part of stderr.'))

helps['bdc settings show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc settings show --settings bdc.telemetry.customerFeedback
        - name: {ex2}
          text: >
            azdata bdc settings show --recursive
        - name: {ex3}
          text: >
            azdata bdc settings show –filter-option=pending --recursive
""".format(
    short=_('Show cluster-scope settings or all cluster settings using --recursive.'),
    long=_('Shows the BDC\'s cluster-level settings. By default, this command shows user-configured cluster-scope '
           'settings. Other filters are available to show all settings (system-managed & user-configurable & '
           'inherited), all configurable settings, or pending settings. To see a specific cluster-scope setting, you '
           'can provide the setting name. If you want to see settings at all scopes (cluster, service, and resource), '
           'you can specify "recursive".'),
    ex1=_('Show whether BDC telemetry collection is enabled.'),
    ex2=_('Show user configured settings in the BDC at all scopes.'),
    ex3=_('Show all pending settings in the BDC at all scopes.'))

helps['bdc sql settings show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc sql settings show
        - name: {ex2}
          text: >
            azdata bdc sql settings show --settings mssql.maxServerMemory --resources data-0
        - name: {ex3}
          text: >
            azdata bdc sql settings show --filter-options=pending --recursive
""".format(
    short=_('Show sql service-scope settings and optionally sql settings for specified resources'),
    long=_('Shows the BDC\'s sql service-scope (optionally resource-scope) settings. By default, this command shows '
           'user-configured service-scope settings. Filters are available to show all settings (system-managed and '
           'configurable), configurable settings, or pending settings. To see a specific service-scope or '
           'resource-scope setting, you can provide the setting name. Use “recursive” to show settings for all '
           'resources as part of the service.'),
    ex1=_('Show the user configured SQL service-scope settings.'),
    ex2=_('Show the max server memory SQL configuration in the Data Pool.'),
    ex3=_('Show the pending settings changes for the SQL service-scope and resource-scope settings.'))

helps['bdc spark settings show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc spark settings show
        - name: {ex2}
          text: >
            azdata bdc spark settings show --settings spark-defaults-conf.spark.driver.cores --resources storage-0
        - name: {ex3}
          text: >
            azdata bdc spark settings show --settings *memory* --resources storage-0
""".format(
    short=_('Show spark service-scope settings and optionally spark settings for specified resources'),
    long=_('Shows the BDC\'s spark service-scope (optionally resource-scope) settings. By default, this command shows '
           'user-configured service-scope settings. Filters are available to show all settings (system-managed and '
           'configurable), configurable settings, or pending settings. To see a specific service-scope or '
           'resource-scope setting, you can provide the setting name. Use “recursive” to show settings for all '
           'resources as part of the service.'),
    ex1=_('Show the user configured Spark service-scope settings.'),
    ex2=_('Show the running and configured value for Spark driver cores in the Storage Pool.'),
    ex3=_('Show any configurable memory-related setting for the Spark service.'))

helps['bdc hdfs settings show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs settings show
        - name: {ex2}
          text: >
            azdata bdc hdfs settings show --settings hdfs-site.dfs.replication --resources storage-0
        - name: {ex3}
          text: >
            azdata bdc hdfs settings show --filter-options=pending --recursive
""".format(
    short=_('Show hdfs service-scope settings and optionally hdfs settings for specified resources'),
    long=_('Shows the BDC\'s hdfs service-scope (optionally resource-scope) settings. By default, this command shows '
           'user-configured service-scope settings. Filters are available to show all settings (system-managed and '
           'configurable), configurable settings, or pending settings. To see a specific service-scope or '
           'resource-scope setting, you can provide the setting name. Use “recursive” to show settings for all '
           'resources as part of the service.'),
    ex1=_('Show the user configured HDFS service-scope settings.'),
    ex2=_('Show the replication factor for HDFS in the Storage Pool.'),
    ex3=_('Show the pending settings changes for the HDFS service-scope and resource-scope settings.'))

helps['bdc gateway settings show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc gateway settings show
        - name: {ex2}
          text: >
            azdata bdc gateway settings show --settings gateway-site.gateway.httpclient.socketTimeout --resources gateway
        - name: {ex3}
          text: >
            azdata bdc gateway settings show --filter-options=pending –-resource gateway
""".format(
    short=_('Show gateway service-scope settings and optionally gateway settings for specified resources'),
    long=_(
        'Shows the BDC\'s gateway service-scope (optionally resource-scope) settings. By default, this command shows '
        'user-configured service-scope settings. Filters are available to show all settings (system-managed and '
        'configurable), configurable settings, or pending settings. To see a specific service-scope or '
        'resource-scope setting, you can provide the setting name. Use “recursive” to show settings for all '
        'resources as part of the service.'),
    ex1=_('Show the user configured Gateway resource-scope settings.'),
    ex2=_('Show the gateway timeout limit.'),
    ex3=_('Show the pending settings changes for the Gateway resource..'))

helps['bdc settings revert'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc settings revert
        - name: {ex2}
          text: >
            azdata bdc settings revert --force
""".format(
    short=_('Reverts pending settings changes in the BDC at all scopes.'),
    long=_('Reverts pending settings changes in the BDC at all scopes.'),
    ex1=_('Revert the BDC\'s pending settings changes at all scopes.'),
    ex2=_('Force revert, the user will not be prompted for any confirmation and all issues will be printed as '
          'part of stderr.'))
