# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def load_arguments(self, _):
    from knack.arguments import ArgumentsContext
    from azdata.cli.commands.distcp import _

    with ArgumentsContext(self, "bdc hdfs distcp submit") as arg_context:
        arg_context.argument(
            "from_path",
            options_list=["--from-path", "-f"],
            help=_("Name of the path to copy from."),
        )

        arg_context.argument(
            "to_path",
            options_list=["--to-path", "-t"],
            help=_("Name of the path to copy to."),
        )
        arg_context.argument(
            "preserve",
            options_list=["--preserve","-p"],
            help=_(
                "Preserve r: replication number b: block size u: user g: group p: permission c: checksum-type a: ACL x: XAttr t: timestamp."
            ),
        )
        arg_context.argument(
            "ignoreFailure",
            options_list=["--ignore-failure","-i"],
            action="store_true",
            help=_("Ignore failures."),
        )
        arg_context.argument(
            "log", options_list=["--log"], help=_("Write logs to <logdir>.")
        )
        arg_context.argument(
            "num_maps",
            options_list=["--num-maps","-m"],
            help=_("Maximum number of simultaneous copies."),
        )
        arg_context.argument(
            "overwrite",
            options_list=["--overwrite"],
            action="store_true",
            help=_("Overwrite destination."),
        )
        arg_context.argument(
            "update",
            options_list=["--update"],
            action="store_true",
            help=_(
                "Overwrite if source and destination differ in size, blocksize, or checksum."
            ),
        )
        arg_context.argument(
            "append",
            options_list=["--append"],
            action="store_true",
            help=_(
                "Incremental copy of file with same name but different length."
            ),
        )
        arg_context.argument(
            "filters",
            options_list=["--filters"],
            help=_(
                "The path to a file containing a list of pattern strings, one string per line, such that paths matching the pattern will be excluded from the copy."
            ),
        )
        arg_context.argument(
            "delete",
            options_list=["--delete"],
            action="store_true",
            help=_("Delete the files existing in the dst but not in src."),
        )
        arg_context.argument(
            "strategy",
            options_list=["--strategy"],
            help=_("Choose the copy-strategy to be used in DistCp."),
        )
        arg_context.argument(
            "bandwidth",
            options_list=["--bandwidth"],
            help=_("Specify bandwidth per map, in MB/second."),
        )
        arg_context.argument(
            "atomic",
            options_list=["--atomic"],
            help=_("Specify atomic."),
        )
        arg_context.argument(
            "diff",
            options_list=["--diff"],
            help=_("Specify diff."),
        )
        arg_context.argument(
            "rdiff",
            options_list=["--rdiff"],
            help=_("Specify rdiff."),
        ) 
        arg_context.argument(
            "numListstatusThreads",
            options_list=["--numListstatusThreads"],
            help=_("Number of threads to use for building file listing."),
        )
        arg_context.argument(
            "skipcrccheck",
            options_list=["--skipcrccheck"],
            action="store_true",
            help=_(
                "Whether to skip CRC checks between source and target paths."
            ),
        )
        arg_context.argument(
            "blocksperchunk",
            options_list=["--blocksperchunk"],
            help=_(
                "Number of blocks per chunk. When specified, split files into chunks to copy in parallel."
            ),
        )
        arg_context.argument(
            "copybuffersize",
            options_list=["--copybuffersize"],
            help=_(
                "Size of the copy buffer to use. By default, <copybuffersize> is set to 8192B."
            ),
        )
        arg_context.argument(
            "xtrack",
            options_list=["--xtrack"],
            help=_(
                "Save information about missing source files to the specified path."
            ),
        )
        arg_context.argument(
            "direct",
            options_list=["--direct"],
            action="store_true",
            help=_("Write directly to destination paths."),
        )

        arg_context.argument(
            'configuration',
            options_list=['--config', '-c'],
            help=_('List of name value pairs containing configuration values. Example of --config value: \'{"mapreduce.map.memory.mb":"4096", "mapred.map.max.attempts":"10"}\'')
        )

    with ArgumentsContext(self, "bdc hdfs distcp status") as arg_context:
        arg_context.argument(
            "job_id",
            options_list=["--job-id", "-i"],
            help=_("Distcp jobId number."),
        )
    with ArgumentsContext(self, "bdc hdfs distcp log") as arg_context:
        arg_context.argument(
            "job_id",
            options_list=["--job-id", "-i"],
            help=_("Distcp job-id number."),
        )
    with ArgumentsContext(self, "bdc hdfs distcp state") as arg_context:
        arg_context.argument(
            "job_id",
            options_list=["--job-id", "-i"],
            help=_("Distcp job-id number."),
        )
    with ArgumentsContext(self, "bdc hdfs distcp list") as arg_context:
        pass
