# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
from azdata.cli.commands.distcp.exceptions import DistcpError
from azdata.cli.core.exceptions import CliError
from azdata.cli.core.logging import get_logger

logger = get_logger(__name__)


def distcp_copy(
    client,
    from_path,
    to_path,
    preserve=None,
    ignoreFailure=None,
    log=None,
    num_maps=None,
    overwrite=None,
    update=None,
    append=None,
    filters=None,
    delete=None,
    strategy=None,
    bandwidth=None,
    atomic=None,
    diff=None,
    rdiff=None,
    numListstatusThreads=None,
    skipcrccheck=None,
    blocksperchunk=None,
    copybuffersize=None,
    xtrack=None,
    direct=None,
    configuration=None,
):
    """
    Submit the async distributed data copy job to copy from-path to the target path.
    :param from_path
    :param to_path
    :param preserve
    :param ignoreFailure
    :param log
    :param num_maps
    :param overwrite
    :param update
    :param append
    :param filters
    :param delete
    :param strategy
    :param bandwidth
    :param atomic
    :param diff
    :param rdiff
    :param numListstatusThreads
    :param skipcrccheck
    :param blocksperchunk
    :param copybuffersize
    :param xtrack
    :param direct
    :param configuration
    """
    try:
        stdout = client.stdout
        if from_path.startswith("https"):
            from_path = from_path.replace("https", "swebhdfs", 1)
        if to_path.startswith("https"):
            to_path = to_path.replace("https", "swebhdfs", 1)
        result = client.job_copy(
            from_path,
            to_path,
            update=update,
            preserve=preserve,
            ignoreFailure=ignoreFailure,
            log=log,
            maps=num_maps,
            overwrite=overwrite,
            append=append,
            filters=filters,
            delete=delete,
            strategy=strategy,
            bandwidth=bandwidth,
            blocksperchunk=blocksperchunk,
            atomic=atomic,
            diff=diff,
            rdiff=rdiff,
            numListstatusThreads=numListstatusThreads,
            skipcrccheck=skipcrccheck,
            copybuffersize=copybuffersize,
            xtrack=xtrack,
            direct=direct,
            configuration=configuration,
        )
        logger.debug(result)
        stdout(result)
    except DistcpError as ex:
        raise CliError(ex)


def distcp_job_status(client, job_id):
    """
    Get the json response status of the provided job-id
    :param job-id return as a result of distcp submit command.
    """
    try:
        stdout = client.stdout  # handle to stdout to display messages
        result = client.job_info(job_id)
        logger.debug(result)
        stdout(result)
    except DistcpError as ex:
        raise CliError(ex)


def distcp_job_list(client):
    """
    List all running distcp jobs
    :param job-id return as a result of distcp submit command.
    """
    try:
        stdout = client.stdout
        result = client.job_list()
        logger.debug(result)
        stdout(result)
    except DistcpError as ex:
        raise CliError(ex)


def distcp_job_log(client, job_id):
    """
    Get the detailed log of the provided job-id
    :param job-id return as a result of distcp submit command.
    """
    try:
        stdout = client.stdout
        result = client.job_log(job_id=job_id)
        logger.debug(result)
        stdout(result)
    except DistcpError as ex:
        raise CliError(ex)


def distcp_job_state(client, job_id):
    """
    Get the distcp job  state of the provided job-id
    :param job-id return as a result of distcp submit command.
    """
    try:
        stdout = client.stdout
        result = client.job_state(job_id=job_id)
        logger.debug(result)
        stdout(result)
    except DistcpError as ex:
        raise CliError(ex)
