# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from knack.help_files import helps
from azdata.cli.commands.distcp import _


# pylint: disable=line-too-long
helps[
    "bdc hdfs distcp"
] = """
    type: group
    short-summary: {short}
""".format(
    short=_("Inter/Intra-cluster distributed data copy.")
)

# pylint: disable=line-too-long
helps[
    "bdc hdfs distcp submit"
] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs distcp submit --from-path https://knox.test.azdata.local:30443/invoices/2020 --to-path /user/invoices/2020
""".format(
    short=_("Copy files/folder from source cluster to target."),
    long=_(
        "Copy files or folder from the source cluster to the destination in a distributed way."
        "We support the following scenarios:"
        "1) distcp between non-secure clusters: remote cluster's credentials can be specified by DISTCP_AZDATA_USERNAME and DISTCP_AZDATA_PASSWORD."
        "2) distcp between a non-secure and a secure cluster: we only support running the command in secure cluster, and user should specify remote"
        "   cluster's credential in env variable DISTCP_AZDATA_USERNAME/DISTCP_AZDATA_PASSWORD. As long as these two env variables exist, we will"
        "   treat remote cluster as non-secure cluster. Note that user should also specify Kerberos keytab in env variable DISTCP_KRB5KEYTAB for"
        "   the tool to submit the distcp job to local secure cluster."
        "3) distcp between secure clusters: we assume both clusters use the same Active Directory domain, user should specify Kerberos keytab"
        "   through DISTCP_KRB5KEYTAB to access both remote and local secure clusters."
        "We support a subset of the distcp command options documented https://hadoop.apache.org/docs/r3.1.3/hadoop-distcp/DistCp.html:"
        "  '-p'"
        "  '-i'"
        "  '-m'"
        "  '-overwrite'"
        "  '-update'"
        "  '-append'"
        "  '-delete'"
        "  '-strategy'"
        "  '-bandwidth'"
        "  '-atomic'"
        "  '-diff'"
        "  '-numListstatusThreads'"
        "  '-skipcrccheck'"
        "  '-blocksperchunk'"
        "  '-copybuffersize'"
        "  '-xtrack'"
        "  '-direct'"
        "Note that the URL for remote BDC should be 'https://<remote-bdc-dns>:30443/<dfs-path>', the URL for local cluster HDFS should be non-prefix"
        "path, e.g.: '/user/invoices/2020'."
    ),
    ex1=_(
        "Copy folder from remote cluster 'knox.test.azdata.local' folder 'invoices/2020' to the logged-in target cluster at folder '/user/invoices/2020'."
    ),
)

helps[
    "bdc hdfs distcp status"
] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs distcp status --job-id 0
""".format(
    short=_("Check the status of distcp job."),
    long=_(
        "This gets the job status including application id, logs and execution state for a distcp job with the given ID. The job id is returned from 'hdfs distcp submit'."
    ),
    ex1=_("Check the status of distcp job with ID of 0."),
)

helps[
    "bdc hdfs distcp list"
] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs distcp list
""".format(
    short=_("List all active distcp job."),
    ex1=_("List all active distcp job."),
)

helps[
    "bdc hdfs distcp log"
] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs distcp log --job-id 0
""".format(
    short=_("Get execution logs for a distcp job."),
    long=_(
        "This gets the log entries for a distcp job with the given ID. The job id is returned from 'hdfs distcp submit'."
    ),
    ex1=_("Get log for a job with ID of 0."),
)

helps[
    "bdc hdfs distcp state"
] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs distcp state --job-id 0
""".format(
    short=_("Get execution state for a distcp job."),
    long=_(
        "This gets the execution state for a distcp job with the given ID, e.g. 'starting', 'running', 'success', 'dead'. The job id is returned from 'hdfs distcp submit'."
    ),
    ex1=_("Get the execution state for a job with ID of 0."),
)
