# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from knack.help_files import helps
from azdata.cli.commands.hdfsencryptionzone import _


# pylint: disable=line-too-long
helps['bdc hdfs encryption-zone'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Manage encryption zones in HDFS.'))

helps['bdc hdfs encryption-zone create'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs encryption-zone create --path /home/securefolder --keyname securelake
""".format(
    short=_('Converts an HDFS folder to an encryption zone.'),
    long=_('Converts an HDFS folder to an encryption zone by using the provided key to encrypt the files in the encryption zone.'),
    ex1=_('To convert an existing folder /user/securefolder to an encryption zone, using a key called securelake'))

helps['bdc hdfs encryption-zone list'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs encryption-zone list
""".format(
    short=_('List all encryption zones and the keys associated with encryption zones.'),
    ex1=_('List all encryption zones.'))

helps['bdc hdfs encryption-zone get-file-encryption-info'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs encryption-zone get-file-encryption-info --path /user/securefolder/data.csv
""".format(
    short=_('Get the encryption information for a given HDFS file path.'),
    ex1=_('Get the encryption information for a file at /user/securefolder/data.csv.'))

helps['bdc hdfs encryption-zone status'] = """
    type: command
    short-summary: {short}
""".format(
    short=_('Get the re-encryption status for the HDFS cluster.'))

helps['bdc hdfs encryption-zone reencrypt'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs encryption-zone reencrypt --path /securelake --action start
        - name: {ex2}
          text: >
            azdata bdc hdfs encryption-zone reencrypt --path /securelake --action cancel
""".format(
    short=_('Controls the re-encryption of the encryption zone specified by the --path argument.'),
    ex1=_('Start the re-encryption of the encryption zone securelake.'),
    ex2=_('Cancel the re-encryption of the encryption zone securelake.'))