# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.kms.exceptions import KmsError
from datetime import datetime as dt
from azdata.cli.core.clients.cli_client import CliClient

__all__ = ["beget"]

def beget(_):
    """Client factory"""
    return KmsClientMixin(check_auth=True, check_eula=False)

class KmsClientMixin(CliClient):
    def __init__(self, check_auth=False, check_eula=False):
        """
        :param check_auth: Set to `True` to have this command enforce
                           authentication before running.
        :param check_eula: Set to `True` to have this command enforce eula
                           acceptance before running.
        """

        self._timestamp = dt.fromtimestamp(dt.timestamp(dt.now()))

        super(KmsClientMixin, self).__init__(
            check_auth=check_auth, check_eula=check_eula
        )

    def bdc_kms_update(self, provider, key_attributes, pin, app_name, app_version):
        return self.apis.controller.kms_update(provider, key_attributes, pin, app_name, app_version)

    def bdc_kms_show(self):
        return self.apis.controller.kms_show()
