# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.kms.api.kms_router_api import KmsRouterApi
from azdata.cli.commands.kms.models.kms_key_configuration_request import KmsKeyConfigurationRequest
from azdata.cli.core.clients.controller_client import RefreshRetry
from azdata.cli.core.exceptions import ApiError, ControllerError

# This file contains plugins for ControllerClient. The file name must be controller_service.py so
# that ControllerClient can import this module as plugins.

__all__ = ['KmsResource']
latest_api_version = '2'

# ---------------------------------------------------------------------------- #
# Configuration: /kms/*
# ---------------------------------------------------------------------------- #
class KmsResource():

    @RefreshRetry
    def kms_update(self, provider, key_attributes, pin, app_name, app_version, api_version=latest_api_version):
        """
        Set configuration
        """
        requestBody = KmsKeyConfigurationRequest(provider, key_attributes, pin, app_name, app_version)
        try:
            api = KmsRouterApi(api_client=self.api_client)
            response = api.api_vversion_bdc_kms_config_post(
                api_version,
                body=requestBody)
            return response
        except ApiError as e:
            raise ControllerError(e, status=e.status, response_json=e.response_json)

    @RefreshRetry
    def kms_show(self, api_version=latest_api_version):
        try:
            api = KmsRouterApi(api_client=self.api_client)
            response = api.api_vversion_bdc_kms_config_get(api_version)
            return response
        except ApiError as e:
            raise ControllerError(e, status=e.status, response_json=e.response_json)
