# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.kms.exceptions import KmsError
from azdata.cli.core.exceptions import CliError, ApiError, ControllerError
from azdata.cli.core.logging import get_logger
from azdata.cli.core.prompt import prompt_y_n
import os
from azdata.cli.commands.kms.util import (create_dict_from_cli, key_attributes_as_str, convert_to_list)

logger = get_logger(__name__)

AZDATA_EXTERNAL_KEY_PIN='AZDATA_EXTERNAL_KEY_PIN'
"""
Environment variable name to look for the key pin.
"""

def bdc_kms_update(client, provider, key_attributes=None, app_name=None, app_version=None):
    """
    Update the KMS with the given inputs.
    """
    try:
        key_attributes_dict = None
        pin = os.getenv(AZDATA_EXTERNAL_KEY_PIN)
        if provider != None:
            if provider.lower() == 'external':
                if app_name == None:
                    raise KmsError('--app-name should be provided for {}'.format(provider))
                if app_version == None:
                    raise KmsError('--app-version should be provided for {}'.format(provider))
                if key_attributes == None or len(key_attributes.strip()) == 0:
                    raise KmsError('--key-attributes should be provided for {}'.format(provider))
        try:
            key_attributes_dict = create_dict_from_cli(key_attributes)
        except ValueError as ve:
            raise CliError("--key-attributes was not specified in correct format.")
        response = client.bdc_kms_update(provider, key_attributes_dict, pin, app_name, app_version)
        return convert_to_list(response)
    except ControllerError as e:
        raise CliError(e)
    except KmsError as ex:
        raise CliError(ex)

def bdc_kms_show(client):
    """
    Gets the configuration of the KMS to show
    """
    try:
        response = client.bdc_kms_show()
        return convert_to_list(response)
    except ControllerError as e:
        raise CliError(e)
    except KmsError as ex:
        raise CliError(ex)
