# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

import shlex

def create_dict_from_cli(key_attributes_cli):
    """
    Convert input like a="a",b="val" to a dictionary.
    """
    key_value_separator = '='
    pair_separator = ','
    key_attributes_dict = {}
    if key_attributes_cli != None:
        lexer = shlex.shlex(key_attributes_cli, posix=True)

        # Split tokens by whitespace
        #
        lexer.whitespace_split = True

        # Configure , as a whitespace, so that the input can be 
        # split using a ,
        #
        lexer.whitespace = pair_separator

        # Construct a dictionary object from the split pairs
        #
        key_attributes_dict = dict(pair.split(key_value_separator, 1) for pair in lexer)
    return key_attributes_dict

def key_attributes_as_str(key_attributes_json):
    """
    Converts the json for key attributes, to key value string e.g. a="something",b="somethingelse"
    """
    pair_separator = ','
    key_value_items = []
    for item in key_attributes_json.items():
        key_value_items.append('{}={}'.format(item[0], item[1]))

    return pair_separator.join(key_value_items)

def convert_to_list(response):
    """
    Converts the kms response to a list
    """
    if "keyDetails" in response:
        response = response["keyDetails"]
        result = []
        for item in iter(response):
            key_attributes = item["keyAttributes"]
            key_attributes_str = key_attributes_as_str(key_attributes)
            item["keyAttributes"] = key_attributes_str
            result.append(item)
        return result
    else:
        return response
