# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
import os
import sys

# On some terminals the width can't be determined. This causes an error message
# from MDV.  Since GCI is one place where the terminal width check fails it
# causes an unexpected stderr message and fails some tests checking for empty
# stderr.  As a work around set COLUMNS environment variable before loading mdv.
# Longer term should probably do the detection and use the width where it is
# available instead of a fixed value.
#
os.environ["COLUMNS"] = "80"

#
# Needed for Windows Python 3.8, otherwise the tornado dependency will give
# errors. https://github.com/tornadoweb/tornado/issues/2608
#
# Important! These lines needs to happen before the imports below which pull
# in tornado.
#
if (
    sys.version_info[0] == 3
    and sys.version_info[1] >= 8
    and sys.platform.startswith("win")
):
    import asyncio

    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())

from azdata.cli.core.clients.cli_client import CliClient
from azdata.cli.commands.notebook.environment import NotebookEnvironmentFactory
from azdata.cli.commands.notebook.nbclient import NotebookClient


def beget(_):
    """Client factory"""

    return NotebookClientMixin()


class NotebookClientMixin(CliClient):
    def __init__(self, check_auth=False, check_eula=True):
        """
        :param check_auth: Set to `True` to have this command enforce
                           authentication before running.
        :param check_auth: Set to `True` to have this command enforce eula
                           acceptance beforeenv,  running.
        """
        if os.name == "nt":
            from colorama import init

            init()

        super(NotebookClientMixin, self).__init__(
            check_auth=check_auth, check_eula=check_eula
        )

        # Persist modified profile items immediately before moving onto any
        # notebook executions. The reason for this is a supplied notebook could
        # potentially contain azdata commands that modify the profile itself.
        # This could cause this profile to be out-of-date here with the one on
        # disk modified by the notebook resulting in overwriting that content
        # with this profile content.
        self.profile.persist()

    def execute_notebook_interactive(self, path, env, clear=None):
        NotebookClient(path, NotebookEnvironmentFactory.create(env)).interact(
            clear
        )

    def execute_notebook(
        self, path, env, output_path, output_html, arguments, timeout
    ):
        notebook_output, notebook_html, exception = NotebookClient(
            path, NotebookEnvironmentFactory.create(env)
        ).run(
            self,
            output_path=output_path,
            output_html=output_html,
            arguments=arguments,
            timeout=timeout,
        )

        output = {"Output Notebook": notebook_output}

        if notebook_html is not None:
            output["HTML Conversion"] = notebook_html

        return output, exception

    def render_notebook(self, path, continue_on_error):
        return NotebookClient(path, NotebookEnvironmentFactory.create()).render(
            continue_on_error
        )
