# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def view(client, path, continue_on_error=False):
    output = client.render_notebook(path, continue_on_error)

    # Note: Right now if you return output data from this function it gets
    # printed to the terminal escaped. So for now write to stdout directly. The
    # downside to this is that a caller can't get the output programmatically
    # unless they intercept stdout and nothing writes to stdout in the process
    # (like prompting for input).
    #
    client.stdout(output)


def run(
    client,
    path,
    output_path=None,
    output_html=None,
    arguments=None,
    interactive=None,
    clear=None,
    timeout=600,
    env="base",
):
    if interactive:
        client.execute_notebook_interactive(path, env, clear)
    else:
        output, exception = client.execute_notebook(
            path,
            env,
            output_path=output_path,
            output_html=output_html,
            arguments=arguments,
            timeout=timeout,
        )

        if exception:
            exception.output = output

            # Before raising the exception output the notebook details to stdout
            # so programs can find the output notebook.
            if output is not None:
                client.stdout(output)

            raise exception

        return output
