# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
from azdata.cli.commands.bdc.constants import UNHEALTHY_STATUS
from azdata.cli.commands.bdc.exceptions import ClusterError
from azdata.cli.core.exceptions import CliError
from azdata.cli.core.logging import get_logger

import azdata.cli.core.deploy as util

logger = get_logger(__name__)


def bdc_rotate(client, name):
    """
    Rotates all BDC managed credentials
    :param client:
    :return:
    """
    try:
        stdout = client.stdout

        # -- Check Kubectl Context --
        util.check_and_set_kubectl_context()

        # Verify cluster status is healthy before proceeding
        cluster_status = client.apis.controller.get_bdc_status()["healthStatus"]
        if cluster_status == UNHEALTHY_STATUS:
            raise CliError(
                "Cluster Status is unhealthy, cannot rotate. You"
                " can check status with 'azdata bdc status show'."
            )

        stdout("Rotating cluster AD credentials")
        stdout("")
        stdout(
            "NOTE: Rotating Cluster AD credentials can take a "
            "significant amount of time depending on"
        )
        stdout(
            "configuration, network speed, and the number"
            " of nodes in the cluster."
        )
        stdout("")

        client.rotate_bdc(name)
    except ClusterError as e:
        raise CliError(e) from e
    except ValueError as e:
        raise CliError(e) from e
    except Exception as e:
        raise CliError(e) from e
